<?php


namespace Drupal\commerce_multiorder\Plugin\Commerce\CheckoutPane;

use Drupal\commerce_payment\Plugin\Commerce\CheckoutPane\PaymentInformation as BasePaymentInformation;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides the payment information pane.
 *
 * Disabling this pane will automatically disable the payment process pane,
 * since they are always used together. Developers subclassing this pane
 * should use hook_commerce_checkout_pane_info_alter(array &$panes) to
 * point $panes['payment_information']['class'] to the new child class.
 *
 * @CommerceCheckoutPane(
 *   id = "commerce_multiorder_payment_information",
 *   label = @Translation("Commerce Multiorder Payment information"),
 *   default_step = "order_information",
 *   wrapper_element = "fieldset",
 * )
 */
class PaymentInformation extends BasePaymentInformation implements CommerceMultiorderPaneInterface {

  use CommerceMultiorderCheckoutPaneTrait;

  public function submitOrderAttached(array &$pane_form, FormStateInterface $form_state, array &$complete_form) {
    if ($this->hasOrderAttached()) {
      foreach ($this->getOrderAttached() as $order) {
        $order->setBillingProfile($this->order->getBillingProfile());
        $order->set('payment_gateway', $this->order->get('payment_gateway')
          ->referencedEntities());
        $order->save();
      }
    }
  }
}